docs.rs failed to build oxios-web-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Web dashboard channel for Oxios.
Provides an HTTP server (axum) that serves as the primary
user interface. Implements the [Channel] trait so it plugs
directly into the gateway.